Proteome-Wide Association Study (PWAS) is a protein-centric, gene-based method for conducting genetic association studies.
Read more in our manuscript: https://www.biorxiv.org/content/10.1101/812289v1

An effort to organize and upload to code of PWAS is currently underway (should be completed within a month or so). Meanwhile, feel free to contact us at nadav.brandes@mail.huji.ac.il.
